calc_bets_pnl_checked

Function calc_bets_pnl_checked 

pub fn calc_bets_pnl_checked(bets: &[Bet]) -> Result<Decimal>
Calculates the combined profit and loss for a slice of bets.

Errors

Returns an error if a payoff or the running total overflows.