pub struct Bet { /* private fields */ }Expand description
A bet in a betting market.
Implementations
Sourceimpl Bet
impl Bet
Sourcepub fn from_stake_or_liability(
price: Decimal,
volume: Decimal,
side: BetSide,
) -> Self
pub fn from_stake_or_liability( price: Decimal, volume: Decimal, side: BetSide, ) -> Self
Creates a bet from a stake or liability depending on the bet side.
For BetSide::Back this calls Self::from_stake and for
BetSide::Lay it calls Self::from_liability.
Panics
Panics if side is BetSide::Lay and Self::from_liability panics.
Sourcepub fn from_stake_or_liability_checked(
price: Decimal,
volume: Decimal,
side: BetSide,
) -> Result<Self>
pub fn from_stake_or_liability_checked( price: Decimal, volume: Decimal, side: BetSide, ) -> Result<Self>
Creates a bet from a stake or liability depending on the bet side.
Errors
Returns an error if side is BetSide::Lay and Self::from_liability_checked fails.
Sourcepub fn from_stake(price: Decimal, stake: Decimal, side: BetSide) -> Self
pub fn from_stake(price: Decimal, stake: Decimal, side: BetSide) -> Self
Creates a bet from a given stake.
Sourcepub fn from_liability(price: Decimal, liability: Decimal, side: BetSide) -> Self
pub fn from_liability(price: Decimal, liability: Decimal, side: BetSide) -> Self
Creates a bet from a given liability.
Panics
Panics if the side is not BetSide::Lay, if price is not greater than 1,
or if the stake calculation overflows.
Sourcepub fn from_liability_checked(
price: Decimal,
liability: Decimal,
side: BetSide,
) -> Result<Self>
pub fn from_liability_checked( price: Decimal, liability: Decimal, side: BetSide, ) -> Result<Self>
Creates a bet from a given liability.
Errors
Returns an error if the side is not BetSide::Lay, if price is not greater
than 1, or if the stake calculation overflows.
Sourcepub fn exposure(&self) -> Decimal
pub fn exposure(&self) -> Decimal
Returns the bet’s exposure.
For BACK bets, exposure is positive; for LAY bets, it is negative.
Panics
Panics if the calculation overflows.
Sourcepub fn exposure_checked(&self) -> Result<Decimal>
pub fn exposure_checked(&self) -> Result<Decimal>
Sourcepub fn liability(&self) -> Decimal
pub fn liability(&self) -> Decimal
Returns the bet’s liability.
For BACK bets, liability equals the stake; for LAY bets, it is stake multiplied by (price - 1).
Panics
Panics if the calculation overflows.
Sourcepub fn liability_checked(&self) -> Result<Decimal>
pub fn liability_checked(&self) -> Result<Decimal>
Sourcepub fn profit(&self) -> Decimal
pub fn profit(&self) -> Decimal
Returns the bet’s profit.
For BACK bets, profit is stake * (price - 1); for LAY bets it equals the stake.
Panics
Panics if the calculation overflows.
Sourcepub fn profit_checked(&self) -> Result<Decimal>
pub fn profit_checked(&self) -> Result<Decimal>
Sourcepub fn outcome_win_payoff(&self) -> Decimal
pub fn outcome_win_payoff(&self) -> Decimal
Returns the outcome win payoff.
For BACK bets this is the profit; for LAY bets it is the negative liability.
Panics
Panics if the calculation overflows.
Sourcepub fn outcome_win_payoff_checked(&self) -> Result<Decimal>
pub fn outcome_win_payoff_checked(&self) -> Result<Decimal>
Sourcepub fn outcome_lose_payoff(&self) -> Decimal
pub fn outcome_lose_payoff(&self) -> Decimal
Returns the outcome lose payoff.
For BACK bets this is the negative liability; for LAY bets it is the profit.
Panics
Panics if the calculation overflows.
Sourcepub fn outcome_lose_payoff_checked(&self) -> Result<Decimal>
pub fn outcome_lose_payoff_checked(&self) -> Result<Decimal>
Sourcepub fn hedging_stake(&self, price: Decimal) -> Decimal
pub fn hedging_stake(&self, price: Decimal) -> Decimal
Returns the hedging stake given a new price.
Panics
Panics if price is zero, if this bet’s price is zero on the lay path,
or if the calculation overflows.
Sourcepub fn hedging_stake_checked(&self, price: Decimal) -> Result<Decimal>
pub fn hedging_stake_checked(&self, price: Decimal) -> Result<Decimal>
Returns the hedging stake given a new price.
Errors
Returns an error if price is zero, if this bet’s price is zero on the
lay path, or if the calculation overflows.
Sourcepub fn hedging_bet(&self, price: Decimal) -> Self
pub fn hedging_bet(&self, price: Decimal) -> Self
Sourcepub fn hedging_bet_checked(&self, price: Decimal) -> Result<Self>
pub fn hedging_bet_checked(&self, price: Decimal) -> Result<Self>
Creates a hedging bet for a given price.
Errors
Returns an error if Self::hedging_stake_checked fails.